==> fpythonic-1.0.0.tar.gz: fpythonic-1.0.0/README.md <==
# PyPI fpythonic Namespace Projects

**WARNING: Under Construction**

Collection of Python packages to aid in general software development.
These Python developer libraries consist of Python PyPI namespace
packages all under the **fpythonic.** "namespace."

These tools tend to prefer a functional programming approach yet
still endeavor to remain Pythonic. The name `fpythonic` is a combination
of `fp` for functional programming and the adjective Pythonic.

The `grscheller/fpythonic` PyPI project is a stub which is intended
**NOT TO BE INSTALLED**. The main purpose of it's associated GitHub
repo, `grscheller/fpthonic`, is to host the documentation and serve as
a homepage for the fpythonic namespace projects.

| Python Package | Projects (PyPI) | Source Code (GitHub) |
|:-------------- |:--------------- |:-------------------- |
| fpythonic.circular_array | [fpythonic.circular-array][11] | [fpythonic-circular-array][21] |
| fpythonic.containers | [fpythonic.containers][12] | [fpythonic-containers][22] |
| fpythonic.fp | [fpythonic.fp][13] | [fpythonic-fp][23] |
| fpythonic.iterables | [fpythonic.iterables][14] | [fpythonic-iterables][24] |
| fpythonic.queues | [fpythonic.queues][15] | [fpythonic-queues][25] |
| fpythonic.splitends | [fpythonic.splitends][16] | [fpythonic-splitends][26] |

**WARNING:** If installed or put on `PYTHONPATH`, then `fpythonic` 
namespace projects will fail to load. 

### Detailed Documentation

Detailed pdoc generated [documentation][1] for 
all [fpythonic PyPI Namespace Projects][2].

### License Information

This repo itself, as well as all the Developer Tools namespace projects,
are licensed under the Apache License Version 2.0, January 2004.

See [CHANGELOG.md](./CHANGELOG.md) for ongoing changes.

[1]: https://grscheller.github.io/fpythonic-namespace-projects/
[2]: https://github.com/grscheller/fpythonic-namespace-projects/blob/main/README.md
[11]: https://pypi.org/project/fpythonic.circular-array/
[12]: https://pypi.org/project/fpythonic.containers/
[13]: https://pypi.org/project/fpythonic.fp/
[14]: https://pypi.org/project/fpythonic.iterables/
[15]: https://pypi.org/project/fpythonic.queues/
[16]: https://pypi.org/project/fpythonic.splitends/
[21]: https://github.com/grscheller/fpythonic-circular-array/
[22]: https://github.com/grscheller/fpythonic-containers/
[23]: https://github.com/grscheller/fpythonic-fp/
[24]: https://github.com/grscheller/fpythonic-iterables/
[25]: https://github.com/grscheller/fpythonic-queues/
[26]: https://github.com/grscheller/fpythonic-splitends/

==> fpythonic-1.1.0.tar.gz: fpythonic-1.1.0/README.md <==
# PyPI fpythonic Namespace Projects

**WARNING: Under Construction**

Collection of Python packages to aid in general software development.
These Python developer libraries consist of Python PyPI namespace
packages all under the **fpythonic.** "namespace."

These tools tend to prefer a functional programming approach yet
still endeavor to remain Pythonic. The name `fpythonic` is a combination
of `fp` for functional programming and the adjective Pythonic.

The `grscheller/fpythonic` PyPI project is a stub which is intended
**NOT TO BE INSTALLED**. The main purpose of it's associated GitHub
repo, `grscheller/fpthonic`, is to host the documentation and serve as
a homepage for the fpythonic namespace projects.

| Python Package | Projects (PyPI) | Source Code (GitHub) |
|:-------------- |:--------------- |:-------------------- |
| fpythonic.circular_array | [fpythonic.circular-array][11] | [fpythonic-circular-array][21] |
| fpythonic.containers | [fpythonic.containers][12] | [fpythonic-containers][22] |
| fpythonic.fp | [fpythonic.fp][13] | [fpythonic-fp][23] |
| fpythonic.iterables | [fpythonic.iterables][14] | [fpythonic-iterables][24] |
| fpythonic.queues | [fpythonic.queues][15] | [fpythonic-queues][25] |
| fpythonic.splitends | [fpythonic.splitends][16] | [fpythonic-splitends][26] |

**WARNING:** If installed or put on `PYTHONPATH`, then `fpythonic` 
namespace projects will fail to load. 

### Detailed Documentation

Detailed pdoc generated [documentation][1] for 
all [fpythonic PyPI Namespace Projects][2].

### License Information

This repo itself, as well as all the Developer Tools namespace projects,
are licensed under the Apache License Version 2.0, January 2004.

See [CHANGELOG.md](./CHANGELOG.md) for ongoing changes.

[1]: https://grscheller.github.io/fpythonic/
[2]: https://github.com/grscheller/fpythonic/blob/main/README.md
[11]: https://pypi.org/project/fpythonic.circular-array/
[12]: https://pypi.org/project/fpythonic.containers/
[13]: https://pypi.org/project/fpythonic.fp/
[14]: https://pypi.org/project/fpythonic.iterables/
[15]: https://pypi.org/project/fpythonic.queues/
[16]: https://pypi.org/project/fpythonic.splitends/
[21]: https://github.com/grscheller/fpythonic-circular-array/
[22]: https://github.com/grscheller/fpythonic-containers/
[23]: https://github.com/grscheller/fpythonic-fp/
[24]: https://github.com/grscheller/fpythonic-iterables/
[25]: https://github.com/grscheller/fpythonic-queues/
[26]: https://github.com/grscheller/fpythonic-splitends/
